pub struct GitGraphData { /* private fields */ }Implementations
Sourceimpl GitGraphData
impl GitGraphData
pub fn get( &self, id: Id<ToEnrichedCommit>, ) -> Option<&EnrichedGitCommit<Id<ToEnrichedCommit>>>
pub fn get_by_hash(&self, h: &GitHash) -> Option<Id<ToEnrichedCommit>>
pub fn unchecked_push( &mut self, commit: GitCommit<Id<ToEnrichedCommit>>, ) -> Result<Id<ToEnrichedCommit>, MoreThanU32Commits>
pub fn history_as_btreeset_from( &self, id: Id<ToEnrichedCommit>, ) -> BTreeSet<Id<ToEnrichedCommit>>
Sourcepub fn closest_matching_ancestor_of(
&self,
for_id: Id<ToEnrichedCommit>,
is_match: impl Fn(Id<ToEnrichedCommit>) -> bool,
) -> Result<Option<Id<ToEnrichedCommit>>>
pub fn closest_matching_ancestor_of( &self, for_id: Id<ToEnrichedCommit>, is_match: impl Fn(Id<ToEnrichedCommit>) -> bool, ) -> Result<Option<Id<ToEnrichedCommit>>>
Find the ancestor commit that is closest to for_id; “close”
means least steps as long as on a branch; when there are
multiple branches (bevore a merge) the commit with the newer
commit time is chosen. It is guaranteed that the id passed to
is_match is contained in self.
pub fn sorted_by<T: Ord>( &self, commits: &BTreeSet<Id<ToEnrichedCommit>>, by: impl FnMut(&EnrichedGitCommit<Id<ToEnrichedCommit>>) -> T, ) -> Vec<Id<ToEnrichedCommit>>
pub fn ids_as_commits<'s: 'ids, 'ids>( &'s self, ids: &'ids [Id<ToEnrichedCommit>], ) -> impl DoubleEndedIterator<Item = &'s EnrichedGitCommit<Id<ToEnrichedCommit>>> + ExactSizeIterator + use<'s, 'ids>
pub fn commits(&self) -> &[EnrichedGitCommit<Id<ToEnrichedCommit>>]
pub fn add_history_from_dir_ref( &mut self, in_directory: impl AsRef<Path>, entry_reference: &str, ) -> Result<GitEntrypoint>